#' topic_modelling.R
#' 
#' contributors: 
#'
#' What this file does"
#' - Explores the stm package for topic modelling as applied to cardiology reviews
#'

# --- Library --- #
library(readr)      # Read in Data
library(dplyr)      # Data Manipulation
library(tibble)     # Working with Dataframes
library(tidytext)   # Workhorse text as data
library(stm)        # Structural Topic Modelling
library(ggplot2)    # Plotting

# --- Load Tokenized Data --- # 
YOURCODE


# --- Establish a Vocab List --- #
YOURCODE

# --- Create Doc-Term-Matrix --- #
YOURCODE

# --- Model! --- #
YOURCODE

# --- Explore Output --- #
YOUR CODE 

# top 10 words per topic visualized
YOUR CODE 

YOURCODE %>%
    group_by(topic) %>%
    top_n(10, beta) %>%
    ungroup() %>%
    mutate(topic = paste0("Topic ", topic),
           term = reorder_within(term, beta, topic)) %>%
    ggplot(aes(term, beta, fill = as.factor(topic))) +
    geom_col(alpha = 0.8, show.legend = FALSE) +
    facet_wrap(~ topic, scales = "free_y") +
    coord_flip() +
    scale_x_reordered() +
    labs(x = NULL, y = expression(beta),
         title = "Highest word probabilities for each topic",
         subtitle = "Different words are associated with different topics")

# --- Assigning Topic Labels --- #
# Suppose we want to assign human readable labels to topics:
td_beta <- 
    td_beta %>%
    mutate(topic_name = case_when(
        topic == 1 ~ "topic 1", # ie. name it something meaningful,
        topic == 2 ~ "topic 2",
        topic == 3 ~ "topic 3",
        topic == 4 ~ "topic 4",
        topic == 5 ~ "topic 5",
        topic == 6 ~ "topic 6",
        TRUE ~ "topic 7"
        )
    )

# re-do your graph from above

# --- Assigning Topics to Reviews --- #
td_gamma <- 
    tidy(YOURCODE, 
         matrix = "gamma",                    
         document_names = rownames(YOURCODE)
    ) %>%
    arrange(as.numeric(document), desc(gamma))


# give each review its most probable topic..
reviews_gamma <- 
    td_gamma %>%
    rename(id = document) %>%
    mutate(id = as.numeric(id)) %>%
    group_by(id) %>%
    slice_max(gamma) %>%
    select(-gamma)

# --- Extras --- #
# IF TIME